@@ -112,24 +112,28 @@ static void play_preview_cb (GtkButton *button, gpointer user_data)
 	if(!filename || !strlen(filename) )
 	{
 		g_free(filename);
-		return show_play_error(_("Sound not set for this event.") );
+		show_play_error(_("Sound not set for this event.") );
+		return;
 	}
 
 	if('/' != filename[0] )
 	{
 		temp = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_SOUND, filename, TRUE, NULL);
 		g_free(filename);
-		if(!temp)
-			return show_play_error(_("The sound file for this event does not exist.\n"
+		if(!temp) {
+			show_play_error(_("The sound file for this event does not exist.\n"
 									 "You may want to install the gnome-audio package "
 									 "for a set of default sounds.") );
+			return;
+		}
 		filename = temp;
 	}
 
 	if(! g_file_test (filename, G_FILE_TEST_EXISTS) )
 	{
 		g_free(filename);
-		return show_play_error(_("The sound file for this event does not exist.") );
+		show_play_error(_("The sound file for this event does not exist.") );
+		return;
 	}
 
     gnome_sound_play (filename);
@@ -148,6 +152,8 @@ static void combo_box_changed_cb(GtkComboBox *combo, gpointer user_data)
 	else if(active_index == MAPPING_SIZE) //ie they want the file chooser
 	{
 		gboolean valid_wav_file_chosen = FALSE;
+		GtkWidget *dialog;
+
 		if(info->old_active_index < MAPPING_SIZE)
 			filename = mapping_filenames[info->old_active_index];
 		else
@@ -157,15 +163,17 @@ static void combo_box_changed_cb(GtkComboBox *combo, gpointer user_data)
 			filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_SOUND, filename, TRUE, NULL);
         filename = g_path_get_dirname(filename);
 
-		GtkWidget *dialog = gtk_file_chooser_dialog_new(_("Select Sound File"), NULL,
+		dialog = gtk_file_chooser_dialog_new(_("Select Sound File"), NULL,
 			GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 			GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
 		gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), filename);
 
 		while(!valid_wav_file_chosen && gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
 		{
+			gchar *mime_type;
+
 			filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-			gchar *mime_type = gnome_vfs_get_mime_type (filename);
+			mime_type = gnome_vfs_get_mime_type (filename);
             if (mime_type && !strcmp (mime_type, "audio/x-wav") )
 			{
 				valid_wav_file_chosen = TRUE;
@@ -186,8 +194,10 @@ static void combo_box_changed_cb(GtkComboBox *combo, gpointer user_data)
 		gtk_widget_destroy(dialog);
 		if(valid_wav_file_chosen)
 		{
+			gchar *temp;
+
 			info->full_filename = g_strdup(filename);
-			gchar *temp = g_filename_display_basename(filename);
+			temp = g_filename_display_basename(filename);
 			gtk_combo_box_remove_text(combo, MAPPING_SIZE + 1);
 			gtk_combo_box_append_text(combo, temp);
 			g_free(temp);
@@ -249,12 +259,14 @@ add_sound_item (GtkTable *table, SoundView *view, SoundEvent *event)
 {
 	GtkWidget *label;
 	GtkWidget *combo;
+	GtkWidget *play_button;
 	gint index;
 	ComboBoxEntryInfo *info;
+	gchar *temp;
 
 	info = g_new0(ComboBoxEntryInfo, 1);
 
-	gchar *temp = generate_event_label(event);
+	temp = generate_event_label(event);
 	label = gtk_label_new_with_mnemonic (temp);
 	g_free(temp);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -275,7 +287,7 @@ add_sound_item (GtkTable *table, SoundView *view, SoundEvent *event)
 	if(-1 == index)
 	{
 		info->full_filename = g_strdup(event->file);
-		gchar *temp = g_filename_display_basename(event->file);
+		temp = g_filename_display_basename(event->file);
 		//printf("Debug - result of g_filename_display_basename is %s\n", temp);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), temp);
 		g_free(temp);
@@ -286,7 +298,7 @@ add_sound_item (GtkTable *table, SoundView *view, SoundEvent *event)
 		if(event->oldfile)
 		{
 			info->full_filename = g_strdup(event->oldfile);
-			gchar *temp = g_filename_display_basename(event->oldfile);
+			temp = g_filename_display_basename(event->oldfile);
 			//printf("Debug - result of old g_filename_display_basename is %s\n", temp);
 			gtk_combo_box_append_text (GTK_COMBO_BOX (combo), temp);
 			g_free(temp);
@@ -305,8 +317,9 @@ add_sound_item (GtkTable *table, SoundView *view, SoundEvent *event)
 		1, 2, table->nrows - 1, table->nrows,
 		GTK_EXPAND | GTK_FILL, GTK_SHRINK, 0, 3);
 
-	GtkWidget *play_button = gtk_button_new();
-	gtk_container_add (GTK_CONTAINER (play_button), gtk_image_new_from_stock (GNOME_STOCK_VOLUME, GTK_ICON_SIZE_SMALL_TOOLBAR));
+	play_button = gtk_button_new ();
+	gtk_container_add (GTK_CONTAINER (play_button),
+			   gtk_image_new_from_stock (GTK_STOCK_MEDIA_PLAY,  GTK_ICON_SIZE_SMALL_TOOLBAR));
 	g_signal_connect (G_OBJECT(play_button), "clicked", (GCallback) play_preview_cb, info);
 	
 	gtk_table_attach (GTK_TABLE (table), play_button,
@@ -339,7 +352,7 @@ sound_view_init (GtkObject *object)
 	view->priv->table = gtk_table_new (1, 3, FALSE);
 	gtk_table_set_col_spacing(GTK_TABLE(view->priv->table), 0, 12);
 	gtk_table_set_col_spacing(GTK_TABLE(view->priv->table), 1, 6);
-	gtk_table_set_row_spacings(GTK_TABLE(view->priv->table), 6);
+	gtk_table_set_row_spacings(GTK_TABLE(view->priv->table), 0);
 	gtk_container_add (GTK_CONTAINER (align), view->priv->table);
 }
 
